DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_syncVentas`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_syncVentas`(
)
    COMMENT 'Recupera la sig. venta pendiente de sincronizar'
BEGIN
    SELECT m.id_movimiento
    FROM tbl_movimientos AS m
    WHERE m.id_tipo_movimiento = 1
        AND m.pagado >= total
        AND m.fecha_cancelado IS NULL
        AND m.consolidado IS NULL
    ORDER BY m.fecha_pago
    LIMIT 1;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_syncVentaDetail`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_syncVentaDetail`(
	in_id_movimiento INT
)
    COMMENT 'Recupera los registros del detalle de una venta'
BEGIN
	SELECT dm.id_producto,
		p.id_unidad_medida,
		CAST(dm.cantidad AS UNSIGNED) AS cantidad,
		dm.precio_venta
	FROM tbl_movimientos_detalle AS dm
	JOIN cat_productos_servicios AS p
		ON p.id_producto = dm.id_producto
	WHERE dm.id_movimiento = in_id_movimiento;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_updateSyncVenta`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_updateSyncVenta`(
	in_id_venta INT
)
    COMMENT 'Marca la venta como sincronizada'
BEGIN
	UPDATE tbl_movimientos
	SET consolidado = NOW()
	WHERE id_movimiento = in_id_venta;
	
	UPDATE tbl_sincronizacion
	SET sync_ventas = NOW();
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_cobroPedido`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_cobroPedido`(
	in_id_movimiento INT,
	in_cobro DECIMAL(15,2),
	in_cambio DECIMAL(15,2),
	in_descuento DECIMAL(15,2),
	in_forma_pago INT,
	in_factura BOOL,
	in_id_user INT,
	in_id_user_descuento INT
)
    SQL SECURITY INVOKER
    COMMENT 'Aplica el cobro a un pedido'
BEGIN
	UPDATE tbl_movimientos
	SET pagado = pagado + in_cobro - in_cambio + in_descuento,
		descuento = descuento + in_descuento,
		fecha_pago = NOW(),
		factura = in_factura,
		id_usuario_pago = in_id_user
	WHERE id_movimiento = in_id_movimiento;
	
	INSERT INTO tbl_movimientos_pagos
	SET id_movimiento = in_id_movimiento,
		importe_cobro = in_cobro,
		cambio = in_cambio,
		descuento = in_descuento,
		id_forma_pago = in_forma_pago,
		fecha_pago = NOW(),
		id_usuario_pago = in_id_user,
		id_usuario_descuento = in_id_user_descuento;
END$$

DELIMITER ;